# Generated by Django 2.2.11 on 2020-03-11 13:54

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("lti_toolbox", "0001_initial"),
        ("forum", "0011_auto_20190627_2132"),
    ]

    operations = [
        migrations.AddField(
            model_name="forum",
            name="lti_consumer",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="lti_toolbox.LTIConsumer",
            ),
        ),
        migrations.AddField(
            model_name="forum",
            name="lti_context",
            field=models.CharField(
                blank=True, db_index=True, max_length=150, null=True
            ),
        ),
    ]
