# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-03 02:50
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("forum_conversation", "0006_post_enable_signature"),
    ]

    operations = [
        migrations.AddField(
            model_name="topic",
            name="first_post",
            field=models.ForeignKey(
                blank=True,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="forum_conversation.Post",
                verbose_name="Last post",
            ),
        ),
        migrations.AddField(
            model_name="topic",
            name="last_post",
            field=models.ForeignKey(
                blank=True,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="forum_conversation.Post",
                verbose_name="Last post",
            ),
        ),
    ]
