# Generated by Django 3.1.7 on 2021-03-02 16:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("forum_conversation", "0013_auto_20201220_1745"),
    ]

    operations = [
        migrations.AlterField(
            model_name="topic",
            name="posts_count",
            field=models.PositiveIntegerField(
                blank=True,
                db_index=True,
                default=0,
                editable=False,
                verbose_name="Posts count",
            ),
        ),
        migrations.AlterField(
            model_name="topic",
            name="views_count",
            field=models.PositiveIntegerField(
                blank=True,
                db_index=True,
                default=0,
                editable=False,
                verbose_name="Views count",
            ),
        ),
    ]
