# Generated by Django 2.2.4 on 2019-08-21 08:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("forum_permission", "0004_auto_20190319_2240"),
    ]

    operations = [
        migrations.AddField(
            model_name="userforumpermission",
            name="authenticated_user",
            field=models.BooleanField(
                db_index=True, default=False, verbose_name="Target any logged in user"
            ),
        ),
    ]
