<div>
    {% include "django/forms/widgets/hidden.html" %}
    <div id="ashley_editor" class="ashley-editor-root ashley-react ashley-react--AshleyEditor"  data-props="{{ widget.props }}" ></div>
</div>
