(self.webpackChunkashley=self.webpackChunkashley||[]).push([[45900],{45900:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"dit jier",1:"folgjend jier",future:{one:"Oer {0} jier",other:"Oer {0} jier"},past:{one:"{0} jier lyn",other:"{0} jier lyn"},"-1":"foarich jier"},"year-short":{0:"dit jier",1:"folgjend jier",future:{one:"Oer {0} jier",other:"Oer {0} jier"},past:{one:"{0} jier lyn",other:"{0} jier lyn"},"-1":"foarich jier"},"year-narrow":{0:"dit jier",1:"folgjend jier",future:{one:"Oer {0} jier",other:"Oer {0} jier"},past:{one:"{0} jier lyn",other:"{0} jier lyn"},"-1":"foarich jier"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"dizze moanne",1:"folgjende moanne",future:{one:"Oer {0} moanne",other:"Oer {0} moannen"},past:{one:"{0} moanne lyn",other:"{0} moannen lyn"},"-1":"foarige moanne"},"month-short":{0:"dizze moanne",1:"folgjende moanne",future:{one:"Oer {0} moanne",other:"Oer {0} moannen"},past:{one:"{0} moanne lyn",other:"{0} moannen lyn"},"-1":"foarige moanne"},"month-narrow":{0:"dizze moanne",1:"folgjende moanne",future:{one:"Oer {0} moanne",other:"Oer {0} moannen"},past:{one:"{0} moanne lyn",other:"{0} moannen lyn"},"-1":"foarige moanne"},week:{0:"dizze wike",1:"folgjende wike",future:{one:"Oer {0} wike",other:"Oer {0} wiken"},past:{one:"{0} wike lyn",other:"{0} wiken lyn"},"-1":"foarige wike"},"week-short":{0:"dizze wike",1:"folgjende wike",future:{one:"Oer {0} wike",other:"Oer {0} wiken"},past:{one:"{0} wike lyn",other:"{0} wiken lyn"},"-1":"foarige wike"},"week-narrow":{0:"dizze wike",1:"folgjende wike",future:{one:"Oer {0} wike",other:"Oer {0} wiken"},past:{one:"{0} wike lyn",other:"{0} wiken lyn"},"-1":"foarige wike"},day:{0:"vandaag",1:"morgen",2:"Oermorgen",future:{one:"Oer {0} dei",other:"Oer {0} deien"},past:{one:"{0} dei lyn",other:"{0} deien lyn"},"-2":"eergisteren","-1":"gisteren"},"day-short":{0:"vandaag",1:"morgen",2:"Oermorgen",future:{one:"Oer {0} dei",other:"Oer {0} deien"},past:{one:"{0} dei lyn",other:"{0} deien lyn"},"-2":"eergisteren","-1":"gisteren"},"day-narrow":{0:"vandaag",1:"morgen",2:"Oermorgen",future:{one:"Oer {0} dei",other:"Oer {0} deien"},past:{one:"{0} dei lyn",other:"{0} deien lyn"},"-2":"eergisteren","-1":"gisteren"},hour:{0:"this hour",future:{one:"Oer {0} oere",other:"Oer {0} oere"},past:{one:"{0} oere lyn",other:"{0} oere lyn"}},"hour-short":{0:"this hour",future:{one:"Oer {0} oere",other:"Oer {0} oere"},past:{one:"{0} oere lyn",other:"{0} oere lyn"}},"hour-narrow":{0:"this hour",future:{one:"Oer {0} oere",other:"Oer {0} oere"},past:{one:"{0} oere lyn",other:"{0} oere lyn"}},minute:{0:"this minute",future:{one:"Oer {0} minút",other:"Oer {0} minuten"},past:{one:"{0} minút lyn",other:"{0} minuten lyn"}},"minute-short":{0:"this minute",future:{one:"Oer {0} minút",other:"Oer {0} minuten"},past:{one:"{0} minút lyn",other:"{0} minuten lyn"}},"minute-narrow":{0:"this minute",future:{one:"Oer {0} minút",other:"Oer {0} minuten"},past:{one:"{0} minút lyn",other:"{0} minuten lyn"}},second:{0:"nu",future:{one:"Oer {0} sekonde",other:"Oer {0} sekonden"},past:{one:"{0} sekonde lyn",other:"{0} sekonden lyn"}},"second-short":{0:"nu",future:{one:"Oer {0} sekonde",other:"Oer {0} sekonden"},past:{one:"{0} sekonde lyn",other:"{0} sekonden lyn"}},"second-narrow":{0:"nu",future:{one:"Oer {0} sekonde",other:"Oer {0} sekonden"},past:{one:"{0} sekonde lyn",other:"{0} sekonden lyn"}}},locale:"fy"})}}]);
//# sourceMappingURL=45900.67a771b23f3fa5c26b30.index.js.map