(self.webpackChunkashley=self.webpackChunkashley||[]).push([[53494],{53494:()=>{!function(){function e(){var e=Array.prototype.slice.call(arguments),t=document.createDocumentFragment();e.forEach((function(e){var n=e instanceof Node;t.appendChild(n?e:document.createTextNode(String(e)))})),this.appendChild(t)}[Element.prototype,Document.prototype,DocumentFragment.prototype].forEach((function(t){t.hasOwnProperty("append")||Object.defineProperty(t,"append",{configurable:!0,enumerable:!0,writable:!0,value:e})}))}()}}]);
//# sourceMappingURL=53494.67a771b23f3fa5c26b30.index.js.map