# Generated by Django 2.1.2 on 2018-10-24 02:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("forum_conversation", "0010_auto_20170120_0224"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="post",
            name="poster_ip",
        ),
    ]
