{% extends "board_base.html" %}
{% load i18n %}

{% block sub_title %}{% trans "Manage forum's moderators" %}{% endblock sub_title %}

{% block content %} 
<div class="row">
  <div class="col-12">
    <h1>{% trans "Manage forum's moderators"%}</h1>
  </div>
</div>
<div class="ashley-react ashley-react--DashboardModerators"></div>
{% endblock content %}

