(self.webpackChunkashley=self.webpackChunkashley||[]).push([[8189],{8189:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"kunan wata",1:"hamuq wata",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"qayna wata"},"year-short":{0:"kunan wata",1:"hamuq wata",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"qayna wata"},"year-narrow":{0:"kunan wata",1:"hamuq wata",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"qayna wata"},quarter:{0:"kunan kimsa killa",1:"hamuq kimsa killa",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"qayna kimsa killa"},"quarter-short":{0:"kunan kimsa killa",1:"hamuq kimsa killa",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"qayna kimsa killa"},"quarter-narrow":{0:"kunan kimsa killa",1:"hamuq kimsa killa",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"qayna kimsa killa"},month:{0:"kunan killa",1:"hamuq killa",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"qayna killa"},"month-short":{0:"kunan killa",1:"hamuq killa",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"qayna killa"},"month-narrow":{0:"kunan killa",1:"hamuq killa",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"qayna killa"},week:{0:"kunan semana",1:"hamuq semana",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"qayna semana"},"week-short":{0:"kunan semana",1:"hamuq semana",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"qayna semana"},"week-narrow":{0:"kunan semana",1:"hamuq semana",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"qayna semana"},day:{0:"kunan punchaw",1:"paqarin",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"qayna punchaw"},"day-short":{0:"kunan punchaw",1:"paqarin",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"qayna punchaw"},"day-narrow":{0:"kunan punchaw",1:"paqarin",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"qayna punchaw"},hour:{0:"kay hora",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-short":{0:"kay hora",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-narrow":{0:"kay hora",future:{other:"+{0} h"},past:{other:"-{0} h"}},minute:{0:"kay minuto",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-short":{0:"kay minuto",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-narrow":{0:"kay minuto",future:{other:"+{0} min"},past:{other:"-{0} min"}},second:{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-short":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-narrow":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}}},locale:"qu-EC"})}}]);
//# sourceMappingURL=8189.67a771b23f3fa5c26b30.index.js.map