{% load i18n %}
{% load custom_tags %}
{% spaceless %}
{% if topic|is_user_instructor:user %}
    <i class="icon_writer fas fa-award" aria-hidden="true" title="{%trans 'Instructor'%}">
    <span class="sr-only">{%trans 'Instructor'%}</span>
    </i>
{% endif %}
{% endspaceless %}