# Generated by Django 3.1.6 on 2021-02-17 13:51

import uuid

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("forum", "0014_auto_20210215_1542"),
    ]

    operations = [
        migrations.AlterField(
            model_name="forum",
            name="lti_id",
            field=models.UUIDField(db_index=True, default=uuid.uuid4, editable=False),
        ),
    ]
