# Generated by Django 2.1.2 on 2018-11-03 19:01

import machina.apps.forum.abstract_models
import machina.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("forum", "0009_auto_20170928_2327"),
    ]

    operations = [
        migrations.AlterField(
            model_name="forum",
            name="image",
            field=machina.models.fields.ExtendedImageField(
                blank=True,
                null=True,
                upload_to=machina.apps.forum.abstract_models.get_forum_image_upload_to,
                verbose_name="Forum image",
            ),
        ),
    ]
