"""
Import the admin classes from the django-machina's forum_permission application
"""

# pylint: disable=unused-wildcard-import,wildcard-import
from machina.apps.forum_permission.admin import *  # noqa isort:skip
