(self.webpackChunkashley=self.webpackChunkashley||[]).push([[68216],{68216:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"esti añu",1:"l’añu viniente",future:{one:"en {0} añu",other:"en {0} años"},past:{one:"hai {0} añu",other:"hai {0} años"},"-1":"l’añu pasáu"},"year-short":{0:"esti añu",1:"l’añu vin.",future:{one:"en {0} añu",other:"en {0} años"},past:{one:"hai {0} añu",other:"hai {0} años"},"-1":"l’añu pas."},"year-narrow":{0:"esti añu",1:"añu vin.",future:{one:"en {0} a.",other:"en {0} a."},past:{one:"hai {0} a.",other:"hai {0} a."},"-1":"añu pas."},quarter:{0:"esti trimestre",1:"trimestre viniente",future:{one:"en {0} trimestre",other:"en {0} trimestres"},past:{one:"hai {0} trimestre",other:"hai {0} trimestres"},"-1":"trimestre anterior"},"quarter-short":{0:"esti trim.",1:"trim. vin.",future:{one:"en {0} trim.",other:"en {0} trim."},past:{one:"hai {0} trim.",other:"hai {0} trim."},"-1":"trim. ant."},"quarter-narrow":{0:"esti trim.",1:"trim. vin.",future:{one:"en {0} tr.",other:"en {0} tr."},past:{one:"hai {0} tr.",other:"hai {0} tr."},"-1":"trim. ant."},month:{0:"esti mes",1:"el mes viniente",future:{one:"en {0} mes",other:"en {0} meses"},past:{one:"hai {0} mes",other:"hai {0} meses"},"-1":"el mes pasáu"},"month-short":{0:"esti mes",1:"mes vin.",future:{one:"en {0} mes",other:"en {0} meses"},past:{one:"hai {0} mes",other:"hai {0} meses"},"-1":"mes pas."},"month-narrow":{0:"esti mes",1:"mes vin.",future:{one:"en {0} m.",other:"en {0} m."},past:{one:"hai {0} m.",other:"hai {0} m."},"-1":"mes pas."},week:{0:"esta selmana",1:"la selmana viniente",future:{one:"en {0} selmana",other:"en {0} selmanes"},past:{one:"hai {0} selmana",other:"hai {0} selmanes"},"-1":"la selmana pasada"},"week-short":{0:"esta selm.",1:"selm. viniente",future:{one:"en {0} selm.",other:"en {0} selm."},past:{one:"hai {0} selm.",other:"hai {0} selm."},"-1":"selm. pasada"},"week-narrow":{0:"esta selm.",1:"selm. vin.",future:{one:"en {0} se.",other:"en {0} se."},past:{one:"hai {0} se.",other:"hai {0} se."},"-1":"selm. pas."},day:{0:"güei",1:"mañana",2:"pasao mañana",future:{one:"en {0} día",other:"en {0} díes"},past:{one:"hai {0} día",other:"hai {0} díes"},"-2":"antayeri","-1":"ayeri"},"day-short":{0:"güei",1:"mañana",2:"pasao mañana",future:{one:"en {0} día",other:"en {0} díes"},past:{one:"hai {0} día",other:"hai {0} díes"},"-2":"antayeri","-1":"ayeri"},"day-narrow":{0:"güei",1:"mañ.",2:"p. mañ.",future:{one:"en {0} d.",other:"en {0} d."},past:{one:"hai {0} d.",other:"hai {0} d."},"-2":"antay.","-1":"ayeri"},hour:{0:"esta hora",future:{one:"en {0} hora",other:"en {0} hores"},past:{one:"hai {0} hora",other:"hai {0} hores"}},"hour-short":{0:"esta hora",future:{one:"en {0} h.",other:"en {0} h."},past:{one:"hai {0} h.",other:"hai {0} h."}},"hour-narrow":{0:"esta h.",future:{one:"en {0} h.",other:"en {0} h."},past:{one:"hai {0} h.",other:"hai {0} h."}},minute:{0:"esti minutu",future:{one:"en {0} minutu",other:"en {0} minutos"},past:{one:"hai {0} minutu",other:"hai {0} minutos"}},"minute-short":{0:"esti min.",future:{one:"en {0} min.",other:"en {0} min."},past:{one:"hai {0} min.",other:"hai {0} min."}},"minute-narrow":{0:"esti min.",future:{one:"en {0} min.",other:"en {0} min."},past:{one:"hai {0} min.",other:"hai {0} min."}},second:{0:"agora",future:{one:"en {0} segundu",other:"en {0} segundos"},past:{one:"hai {0} segundu",other:"hai {0} segundos"}},"second-short":{0:"agora",future:{one:"en {0} seg.",other:"en {0} seg."},past:{one:"hai {0} seg.",other:"hai {0} seg."}},"second-narrow":{0:"agora",future:{one:"en {0} s.",other:"en {0} s."},past:{one:"hai {0} s.",other:"hai {0} s."}}},locale:"ast"})}}]);
//# sourceMappingURL=68216.67a771b23f3fa5c26b30.index.js.map