(self.webpackChunkashley=self.webpackChunkashley||[]).push([[34345],{34345:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"быел",1:"киләсе елда",future:{other:"{0} елдан"},past:{other:"{0} ел элек"},"-1":"узган ел"},"year-short":{0:"быел",1:"киләсе елда",future:{other:"{0} елдан"},past:{other:"{0} ел элек"},"-1":"узган ел"},"year-narrow":{0:"быел",1:"киләсе елда",future:{other:"{0} елдан"},past:{other:"{0} ел элек"},"-1":"узган ел"},quarter:{0:"бу кварталда",1:"киләсе кварталда",future:{other:"{0} кварталдан"},past:{other:"{0} квартал элек"},"-1":"узган кварталда"},"quarter-short":{0:"бу кварталда",1:"киләсе кварталда",future:{other:"{0} кв."},past:{other:"{0} кв. элек"},"-1":"узган кварталда"},"quarter-narrow":{0:"бу кварталда",1:"киләсе кварталда",future:{other:"{0} кв."},past:{other:"{0} кв. элек"},"-1":"узган кварталда"},month:{0:"бу айда",1:"киләсе айда",future:{other:"{0} айдан"},past:{other:"{0} ай элек"},"-1":"узган айда"},"month-short":{0:"бу айда",1:"киләсе айда",future:{other:"{0} айдан"},past:{other:"{0} ай элек"},"-1":"узган айда"},"month-narrow":{0:"бу айда",1:"киләсе айда",future:{other:"{0} айдан"},past:{other:"{0} ай элек"},"-1":"узган айда"},week:{0:"бу атнада",1:"киләсе атнада",future:{other:"{0} атнадан"},past:{other:"{0} атна элек"},"-1":"узган атнада"},"week-short":{0:"бу атнада",1:"киләсе атнада",future:{other:"{0} атнадан"},past:{other:"{0} атна элек"},"-1":"узган атнада"},"week-narrow":{0:"бу атнада",1:"киләсе атнада",future:{other:"{0} атнадан"},past:{other:"{0} атна элек"},"-1":"узган атнада"},day:{0:"бүген",1:"иртәгә",future:{other:"{0} көннән"},past:{other:"{0} көн элек"},"-1":"кичә"},"day-short":{0:"бүген",1:"иртәгә",future:{other:"{0} көннән"},past:{other:"{0} көн элек"},"-1":"кичә"},"day-narrow":{0:"бүген",1:"иртәгә",future:{other:"{0} көннән"},past:{other:"{0} көн элек"},"-1":"кичә"},hour:{0:"бу сәгатьтә",future:{other:"{0} сәгатьтән"},past:{other:"{0} сәгать элек"}},"hour-short":{0:"бу сәгатьтә",future:{other:"{0} сәг."},past:{other:"{0} сәг. элек"}},"hour-narrow":{0:"бу сәгатьтә",future:{other:"{0} сәг."},past:{other:"{0} сәг. элек"}},minute:{0:"бу минутта",future:{other:"{0} минуттан"},past:{other:"{0} минут элек"}},"minute-short":{0:"бу минутта",future:{other:"{0} мин."},past:{other:"{0} мин. элек"}},"minute-narrow":{0:"бу минутта",future:{other:"{0} мин."},past:{other:"{0} мин. элек"}},second:{0:"хәзер",future:{other:"{0} секундтан"},past:{other:"{0} секунд элек"}},"second-short":{0:"хәзер",future:{other:"{0} с."},past:{other:"{0} с. элек"}},"second-narrow":{0:"хәзер",future:{other:"{0} с."},past:{other:"{0} с. элек"}}},locale:"tt"})}}]);
//# sourceMappingURL=34345.67a771b23f3fa5c26b30.index.js.map