# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2017-01-20 01:24
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("forum_conversation", "0009_auto_20160925_2126"),
    ]

    operations = [
        migrations.AlterField(
            model_name="topic",
            name="first_post",
            field=models.ForeignKey(
                blank=True,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="forum_conversation.Post",
                verbose_name="First post",
            ),
        ),
    ]
