(self.webpackChunkashley=self.webpackChunkashley||[]).push([[88617],{88617:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"ሎሚ ዓመት",1:"ንዓመታ",future:{one:"ኣብ {0} ዓ",other:"ኣብ {0} ዓ"},past:{one:"ቅድሚ {0} ዓ",other:"ቅድሚ {0} ዓ"},"-1":"ዓሚ"},"year-short":{0:"ሎሚ ዓመት",1:"ንዓመታ",future:{one:"ኣብ {0} ዓ",other:"ኣብ {0} ዓ"},past:{one:"ቅድሚ -{0} ዓ",other:"ቅድሚ {0} ዓ"},"-1":"ዓሚ"},"year-narrow":{0:"ሎሚ ዓመት",1:"ንዓመታ",future:{one:"ኣብ {0} ዓ",other:"ኣብ {0} ዓ"},past:{one:"ቅድሚ {0} ዓ",other:"ቅድሚ {0} ዓ"},"-1":"ዓሚ"},quarter:{0:"ህሉው ርብዒ",1:"ዝመጽእ ርብዒ",future:{one:"ኣብ {0} ርብዒ",other:"ኣብ {0} ርብዒ"},past:{one:"ቅድሚ {0} ርብዒ",other:"ቅድሚ {0} ርብዒ"},"-1":"ዝሓለፈ ርብዒ"},"quarter-short":{0:"ህሉው ርብዒ",1:"ዝመጽእ ርብዒ",future:{one:"ኣብ {0} ርብዒ",other:"ኣብ {0} ርብዒ"},past:{one:"ቅድሚ {0} ርብዒ",other:"ቅድሚ {0} ርብዒ"},"-1":"ዝሓለፈ ርብዒ"},"quarter-narrow":{0:"ህሉው ርብዒ",1:"ዝመጽእ ርብዒ",future:{one:"ኣብ {0} ርብዒ",other:"ኣብ {0} ርብዒ"},past:{one:"ቅድሚ {0} ርብዒ",other:"ቅድሚ {0} ርብዒ"},"-1":"ዝሓለፈ ርብዒ"},month:{0:"ህሉው ወርሒ",1:"ዝመጽእ ወርሒ",future:{one:"ኣብ {0} ወርሒ",other:"ኣብ {0} ወርሒ"},past:{one:"ቅድሚ {0} ወርሒ",other:"ቅድሚ {0} ወርሒ"},"-1":"last month"},"month-short":{0:"ህሉው ወርሒ",1:"ዝመጽእ ወርሒ",future:{one:"ኣብ {0} ወርሒ",other:"ኣብ {0} ወርሒ"},past:{one:"ቅድሚ {0} ወርሒ",other:"ቅድሚ {0} ወርሒ"},"-1":"ዝሓለፈ ወርሒ"},"month-narrow":{0:"ህሉው ወርሒ",1:"ዝመጽእ ወርሒ",future:{one:"ኣብ {0} ወርሒ",other:"ኣብ {0} ወርሒ"},past:{one:"ቅድሚ {0} ወርሒ",other:"ቅድሚ {0} ወርሒ"},"-1":"ዝሓለፈ ወርሒ"},week:{0:"ህሉው ሰሙን",1:"ዝመጽእ ሰሙን",future:{one:"ኣብ {0} ሰሙን",other:"ኣብ {0} ሰሙን"},past:{one:"ቅድሚ {0} ሰሙን",other:"ቅድሚ {0} ሰሙን"},"-1":"ዝሓለፈ ሰሙን"},"week-short":{0:"ህሉው ሰሙን",1:"ዝመጽእ ሰሙን",future:{one:"ኣብ {0} ሰሙን",other:"ኣብ {0} ሰሙን"},past:{one:"ቅድሚ {0} ሰሙን",other:"ቅድሚ {0} ሰሙን"},"-1":"ዝሓለፈ ሰሙን"},"week-narrow":{0:"ህሉው ሰሙን",1:"ዝመጽእ ሰሙን",future:{one:"ኣብ {0} ሰሙን",other:"ኣብ {0} ሰሙን"},past:{one:"ቅድሚ {0} ሰሙን",other:"ቅድሚ {0} ሰሙን"},"-1":"ዝሓለፈ ሰሙን"},day:{0:"ሎሚ",1:"ጽባሕ",future:{one:"ኣብ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"},past:{one:"ቅድሚ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"},"-1":"ትማሊ"},"day-short":{0:"ሎሚ",1:"ጽባሕ",future:{one:"ኣብ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"},past:{one:"ቅድሚ {0} መዓልቲ",other:"ቅድሚ {0} መዓልቲ"},"-1":"ትማሊ"},"day-narrow":{0:"ሎሚ",1:"ጽባሕ",future:{one:"ኣብ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"},past:{one:"ቅድሚ {0} መዓልቲ",other:"ቅድሚ {0} መዓልቲ"},"-1":"ትማሊ"},hour:{0:"ኣብዚ ሰዓት",future:{one:"ኣብ {0} ሰዓት",other:"ኣብ {0} ሰዓት"},past:{one:"ቅድሚ {0} ሰዓት",other:"ቅድሚ {0} ሰዓት"}},"hour-short":{0:"ኣብዚ ሰዓት",future:{one:"ኣብ {0} ሰዓት",other:"ኣብ {0} ሰዓት"},past:{one:"ቅድሚ {0} ሰዓት",other:"ቅድሚ {0} ሰዓት"}},"hour-narrow":{0:"ኣብዚ ሰዓት",future:{one:"ኣብ {0} ሰዓት",other:"ኣብ {0} ሰዓት"},past:{one:"ቅድሚ {0} ሰዓት",other:"ቅድሚ {0} ሰዓት"}},minute:{0:"ኣብዚ ደቒቕ",future:{one:"ኣብ {0} ደቒቕ",other:"ኣብ {0} ደቒቕ"},past:{one:"ቅድሚ {0} ደቒቕ",other:"ቅድሚ {0} ደቒቕ"}},"minute-short":{0:"ኣብዚ ደቒቕ",future:{one:"ኣብ {0} ደቒቕ",other:"ኣብ {0} ደቒቕ"},past:{one:"ቅድሚ {0} ደቒቕ",other:"ቅድሚ {0} ደቒቕ"}},"minute-narrow":{0:"ኣብዚ ደቒቕ",future:{one:"ኣብ {0} ደቒቕ",other:"ኣብ {0} ደቒቕ"},past:{one:"ቅድሚ {0} ደቒቕ",other:"ቅድሚ {0} ደቒቕ"}},second:{0:"ሕጂ",future:{one:"ኣብ {0} ካልኢት",other:"ኣብ {0} ካልኢት"},past:{one:"ቅድሚ {0} ካልኢት",other:"ቅድሚ {0} ካልኢት"}},"second-short":{0:"ሕጂ",future:{one:"ኣብ {0} ካልኢት",other:"ኣብ {0} ካልኢት"},past:{one:"ቅድሚ {0} ካልኢት",other:"ቅድሚ {0} ካልኢት"}},"second-narrow":{0:"ሕጂ",future:{one:"ኣብ {0} ካልኢት",other:"ኣብ {0} ካልኢት"},past:{one:"ቅድሚ {0} ካልኢት",other:"ቅድሚ {0} ካልኢት"}}},locale:"ti-ER"})}}]);
//# sourceMappingURL=88617.67a771b23f3fa5c26b30.index.js.map