"""Declare the models related to the forum_permission app ."""

# Import models from the django-machina app
from machina.apps.forum_permission.models import *  # noqa, pylint: disable=unused-wildcard-import,wildcard-import
