(self.webpackChunkashley=self.webpackChunkashley||[]).push([[28598],{28598:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"соли ҷорӣ",1:"соли оянда",future:{other:"пас аз {0} сол"},past:{other:"{0} сол пеш"},"-1":"соли гузашта"},"year-short":{0:"соли ҷ.",1:"соли о.",future:{other:"пас аз {0} с."},past:{other:"{0} с. пеш"},"-1":"соли г."},"year-narrow":{0:"соли ҷ.",1:"соли о.",future:{other:"пас аз {0} с."},past:{other:"{0} с. пеш"},"-1":"соли г."},quarter:{0:"чоряки ҷорӣ",1:"чоряки оянда",future:{other:"пас аз {0} чоряк"},past:{other:"{0} чоряк пеш"},"-1":"чоряки гузашта"},"quarter-short":{0:"чоряки ҷорӣ",1:"чоряки оянда",future:{other:"пас аз {0} чр."},past:{other:"{0} чр. пеш"},"-1":"чоряки гузашта"},"quarter-narrow":{0:"чоряки ҷорӣ",1:"чоряки оянда",future:{other:"пас аз {0} чр."},past:{other:"{0} чр. пеш"},"-1":"чоряки гузашта"},month:{0:"моҳи ҷорӣ",1:"моҳи оянда",future:{other:"пас аз {0} моҳ"},past:{other:"{0} моҳ пеш"},"-1":"моҳи гузашта"},"month-short":{0:"моҳи ҷ.",1:"моҳи о.",future:{other:"пас аз {0} м."},past:{other:"{0} м. пеш"},"-1":"моҳи г."},"month-narrow":{0:"моҳи ҷ.",1:"моҳи о.",future:{other:"пас аз {0} м."},past:{other:"{0} м. пеш"},"-1":"моҳи г."},week:{0:"ҳафтаи ҷорӣ",1:"ҳафтаи оянда",future:{other:"пас аз {0} ҳафта"},past:{other:"{0} ҳафта пеш"},"-1":"ҳафтаи гузашта"},"week-short":{0:"ҳафтаи ҷ.",1:"ҳафтаи о.",future:{other:"пас аз {0} ҳ."},past:{other:"{0} ҳ. пеш"},"-1":"ҳафтаи г."},"week-narrow":{0:"ҳафтаи ҷ.",1:"ҳафтаи о.",future:{other:"пас аз {0} ҳ."},past:{other:"{0} ҳ. пеш"},"-1":"ҳафтаи г."},day:{0:"имрӯз",1:"фардо",future:{other:"пас аз {0} рӯз"},past:{other:"{0} рӯз пеш"},"-1":"дирӯз"},"day-short":{0:"имрӯз",1:"фардо",future:{other:"пас аз {0} рӯз"},past:{other:"{0} рӯз пеш"},"-1":"дирӯз"},"day-narrow":{0:"имрӯз",1:"фардо",future:{other:"пас аз {0} рӯз"},past:{other:"{0} рӯз пеш"},"-1":"дирӯз"},hour:{0:"соати ҷорӣ",future:{other:"пас аз {0} соат"},past:{other:"{0} соат пеш"}},"hour-short":{0:"соати ҷорӣ",future:{other:"пас аз {0} ст."},past:{other:"{0} ст. пеш"}},"hour-narrow":{0:"соати ҷорӣ",future:{other:"пас аз {0} ст."},past:{other:"{0} ст. пеш"}},minute:{0:"дақиқаи ҷорӣ",future:{other:"пас аз {0} дақиқа"},past:{other:"{0} дақиқа пеш"}},"minute-short":{0:"дақиқаи ҷорӣ",future:{other:"пас аз {0} дақ."},past:{other:"{0} дақ. пеш"}},"minute-narrow":{0:"дақиқаи ҷорӣ",future:{other:"пас аз {0} дақ."},past:{other:"{0} дақ. пеш"}},second:{0:"ҳозир",future:{other:"пас аз {0} сония"},past:{other:"{0} сония пеш"}},"second-short":{0:"ҳозир",future:{other:"пас аз {0} сон."},past:{other:"{0} сон. пеш"}},"second-narrow":{0:"ҳозир",future:{other:"пас аз {0} сон."},past:{other:"{0} сон. пеш"}}},locale:"tg"})}}]);
//# sourceMappingURL=28598.67a771b23f3fa5c26b30.index.js.map