(self.webpackChunkashley=self.webpackChunkashley||[]).push([[77221],{77221:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"karong tuiga",1:"sunod nga tuig",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"miaging tuig"},"year-short":{0:"karong tuiga",1:"sunod nga tuig",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"miaging tuig"},"year-narrow":{0:"karong tuiga",1:"sunod nga tuig",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"miaging tuig"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"karong buwana",1:"sunod nga buwan",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"miaging buwan"},"month-short":{0:"karong buwana",1:"sunod nga buwan",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"miaging buwan"},"month-narrow":{0:"karong buwana",1:"sunod nga buwan",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"miaging buwan"},week:{0:"karong semanaha",1:"sunod nga semana",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"miaging semana"},"week-short":{0:"karong semanaha",1:"sunod nga semana",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"miaging semana"},"week-narrow":{0:"karong semanaha",1:"sunod nga semana",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"miaging semana"},day:{0:"karong adlawa",1:"ugma",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"gahapon"},"day-short":{0:"karong adlawa",1:"ugma",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"gahapon"},"day-narrow":{0:"karong adlawa",1:"ugma",future:{other:"+{0} d"},past:{other:"-{0} d"},"-1":"gahapon"},hour:{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-short":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-narrow":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},minute:{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-short":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-narrow":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},second:{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-short":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-narrow":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}}},locale:"ceb"})}}]);
//# sourceMappingURL=77221.67a771b23f3fa5c26b30.index.js.map