(self.webpackChunkashley=self.webpackChunkashley||[]).push([[1891],{1891:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"Ɔdúnǹí",1:"Àmɔ́dún",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Èshín"},"year-short":{0:"Ɔdún yìí",1:"Ɔdún tó ńbɔ̀",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Ɔdún tó kɔjá"},"year-narrow":{0:"Ɔdún yìí",1:"Ɔdún tó ńbɔ̀",future:{other:"+{0} y"},past:{other:"-{0} y"},"-1":"Ɔdún tó kɔjá"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"oshù yìí",1:"óshù tó ń bɔ̀,",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"óshù tó kɔjá"},"month-short":{0:"oshù yìí",1:"óshù tó ń bɔ̀,",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"óshù tó kɔjá"},"month-narrow":{0:"oshù yìí",1:"óshù tó ń bɔ̀,",future:{other:"+{0} m"},past:{other:"-{0} m"},"-1":"óshù tó kɔjá"},week:{0:"ɔ̀sɛ̀ yìí",1:"ɔ́sɛ̀ tó ń bɔ̀",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"ɔ̀sɛ̀ tó kɔjá"},"week-short":{0:"ɔ̀sɛ̀ yìí",1:"ɔ́sɛ̀ tó ń bɔ̀",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"ɔ̀sɛ̀ tó kɔjá"},"week-narrow":{0:"ɔ̀sɛ̀ yìí",1:"ɔ́sɛ̀ tó ń bɔ̀",future:{other:"+{0} w"},past:{other:"-{0} w"},"-1":"ɔ̀sɛ̀ tó kɔjá"},day:{0:"Òní",1:"Ɔ̀la",2:"òtúùnla",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"íjɛta","-1":"Àná"},"day-short":{0:"Òní",1:"Ɔ̀la",2:"òtúùnla",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"íjɛta","-1":"Àná"},"day-narrow":{0:"Òní",1:"Ɔ̀la",2:"òtúùnla",future:{other:"+{0} d"},past:{other:"-{0} d"},"-2":"íjɛta","-1":"Àná"},hour:{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-short":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},"hour-narrow":{0:"this hour",future:{other:"+{0} h"},past:{other:"-{0} h"}},minute:{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-short":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},"minute-narrow":{0:"this minute",future:{other:"+{0} min"},past:{other:"-{0} min"}},second:{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-short":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}},"second-narrow":{0:"now",future:{other:"+{0} s"},past:{other:"-{0} s"}}},locale:"yo-BJ"})}}]);
//# sourceMappingURL=1891.67a771b23f3fa5c26b30.index.js.map