# Generated by Django 2.2.10 on 2020-04-23 15:49

import machina.core.validators
import machina.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("forum_conversation", "0011_remove_post_poster_ip"),
    ]

    operations = [
        migrations.AlterField(
            model_name="post",
            name="content",
            field=machina.models.fields.MarkupTextField(
                no_rendered_field=True,
                validators=[machina.core.validators.MarkupMaxLengthValidator(None)],
                verbose_name="Content",
            ),
        ),
    ]
