{% load i18n %}
{% if col.sorted %} 
    <span class="sortoptions">
        <a href="{{ col.url_order }}" class="toggle {% if col.ascending %}ascending{% else %}descending{% endif %}" title="{% translate "Toggle sorting" %}"></a>
    </span>
{% endif %}
