# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-21 02:31
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("forum_permission", "0002_auto_20160607_0500"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="forumpermission",
            name="name",
        ),
    ]
