# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-07-09 04:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("forum_conversation", "0005_auto_20160607_0455"),
    ]

    operations = [
        migrations.AddField(
            model_name="post",
            name="enable_signature",
            field=models.BooleanField(
                db_index=True, default=True, verbose_name="Attach a signature"
            ),
        ),
    ]
