(self.webpackChunkashley=self.webpackChunkashley||[]).push([[58772],{58772:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"بۇ يىل",1:"كېلەر يىل",future:{one:"{0} يىلدىن كېيىن",other:"{0} يىلدىن كېيىن"},past:{one:"{0} يىل ئىلگىرى",other:"{0} يىل ئىلگىرى"},"-1":"ئۆتكەن يىل"},"year-short":{0:"بۇ يىل",1:"كېلەر يىل",future:{one:"{0} يىلدىن كېيىن",other:"{0} يىلدىن كېيىن"},past:{one:"{0} يىل ئىلگىرى",other:"{0} يىل ئىلگىرى"},"-1":"ئۆتكەن يىل"},"year-narrow":{0:"بۇ يىل",1:"كېلەر يىل",future:{one:"{0} يىلدىن كېيىن",other:"{0} يىلدىن كېيىن"},past:{one:"{0} يىل ئىلگىرى",other:"{0} يىل ئىلگىرى"},"-1":"ئۆتكەن يىل"},quarter:{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-short":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},"quarter-narrow":{0:"this quarter",1:"next quarter",future:{other:"+{0} Q"},past:{other:"-{0} Q"},"-1":"last quarter"},month:{0:"بۇ ئاي",1:"كېلەر ئاي",future:{one:"{0} ئايدىن كېيىن",other:"{0} ئايدىن كېيىن"},past:{one:"{0} ئاي ئىلگىرى",other:"{0} ئاي ئىلگىرى"},"-1":"ئۆتكەن ئاي"},"month-short":{0:"بۇ ئاي",1:"كېلەر ئاي",future:{one:"{0} ئايدىن كېيىن",other:"{0} ئايدىن كېيىن"},past:{one:"{0} ئاي ئىلگىرى",other:"{0} ئاي ئىلگىرى"},"-1":"ئۆتكەن ئاي"},"month-narrow":{0:"بۇ ئاي",1:"كېلەر ئاي",future:{one:"{0} ئايدىن كېيىن",other:"{0} ئايدىن كېيىن"},past:{one:"{0} ئاي ئىلگىرى",other:"{0} ئاي ئىلگىرى"},"-1":"ئۆتكەن ئاي"},week:{0:"بۇ ھەپتە",1:"كېلەر ھەپتە",future:{one:"{0} ھەپتىدىن كېيىن",other:"{0} ھەپتىدىن كېيىن"},past:{one:"{0} ھەپتە ئىلگىرى",other:"{0} ھەپتە ئىلگىرى"},"-1":"ئۆتكەن ھەپتە"},"week-short":{0:"بۇ ھەپتە",1:"كېلەر ھەپتە",future:{one:"{0} ھەپتىدىن كېيىن",other:"{0} ھەپتىدىن كېيىن"},past:{one:"{0} ھەپتە ئىلگىرى",other:"{0} ھەپتە ئىلگىرى"},"-1":"ئۆتكەن ھەپتە"},"week-narrow":{0:"بۇ ھەپتە",1:"كېلەر ھەپتە",future:{one:"{0} ھەپتىدىن كېيىن",other:"{0} ھەپتىدىن كېيىن"},past:{one:"{0} ھەپتە ئىلگىرى",other:"{0} ھەپتە ئىلگىرى"},"-1":"ئۆتكەن ھەپتە"},day:{0:"بۈگۈن",1:"ئەتە",future:{one:"{0} كۈندىن كېيىن",other:"{0} كۈندىن كېيىن"},past:{one:"{0} كۈن ئىلگىرى",other:"{0} كۈن ئىلگىرى"},"-1":"تۈنۈگۈن"},"day-short":{0:"بۈگۈن",1:"ئەتە",future:{one:"{0} كۈندىن كېيىن",other:"{0} كۈندىن كېيىن"},past:{one:"{0} كۈن ئىلگىرى",other:"{0} كۈن ئىلگىرى"},"-1":"تۈنۈگۈن"},"day-narrow":{0:"بۈگۈن",1:"ئەتە",future:{one:"{0} كۈندىن كېيىن",other:"{0} كۈندىن كېيىن"},past:{one:"{0} كۈن ئىلگىرى",other:"{0} كۈن ئىلگىرى"},"-1":"تۈنۈگۈن"},hour:{0:"this hour",future:{one:"{0} سائەتتىن كېيىن",other:"{0} سائەتتىن كېيىن"},past:{one:"{0} سائەت ئىلگىرى",other:"{0} سائەت ئىلگىرى"}},"hour-short":{0:"this hour",future:{one:"{0} سائەتتىن كېيىن",other:"{0} سائەتتىن كېيىن"},past:{one:"{0} سائەت ئىلگىرى",other:"{0} سائەت ئىلگىرى"}},"hour-narrow":{0:"this hour",future:{one:"{0} سائەتتىن كېيىن",other:"{0} سائەتتىن كېيىن"},past:{one:"{0} سائەت ئىلگىرى",other:"{0} سائەت ئىلگىرى"}},minute:{0:"this minute",future:{one:"{0} مىنۇتتىن كېيىن",other:"{0} مىنۇتتىن كېيىن"},past:{one:"{0} مىنۇت ئىلگىرى",other:"{0} مىنۇت ئىلگىرى"}},"minute-short":{0:"this minute",future:{one:"{0} مىنۇتتىن كېيىن",other:"{0} مىنۇتتىن كېيىن"},past:{one:"{0} مىنۇت ئىلگىرى",other:"{0} مىنۇت ئىلگىرى"}},"minute-narrow":{0:"this minute",future:{one:"{0} مىنۇتتىن كېيىن",other:"{0} مىنۇتتىن كېيىن"},past:{one:"{0} مىنۇت ئىلگىرى",other:"{0} مىنۇت ئىلگىرى"}},second:{0:"now",future:{one:"{0} سېكۇنتتىن كېيىن",other:"{0} سېكۇنتتىن كېيىن"},past:{one:"{0} سېكۇنت ئىلگىرى",other:"{0} سېكۇنت ئىلگىرى"}},"second-short":{0:"now",future:{one:"{0} سېكۇنتتىن كېيىن",other:"{0} سېكۇنتتىن كېيىن"},past:{one:"{0} سېكۇنت ئىلگىرى",other:"{0} سېكۇنت ئىلگىرى"}},"second-narrow":{0:"now",future:{one:"{0} سېكۇنتتىن كېيىن",other:"{0} سېكۇنتتىن كېيىن"},past:{one:"{0} سېكۇنت ئىلگىرى",other:"{0} سېكۇنت ئىلگىرى"}}},locale:"ug"})}}]);
//# sourceMappingURL=58772.67a771b23f3fa5c26b30.index.js.map