# Generated by Django 3.1.1 on 2020-09-17 13:35

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("lti_toolbox", "0001_initial"),
        ("ashley", "0002_auto_20200325_1651"),
    ]

    operations = [
        migrations.AlterField(
            model_name="lticontext",
            name="lti_consumer",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.PROTECT,
                to="lti_toolbox.lticonsumer",
            ),
        ),
        migrations.AlterField(
            model_name="user",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=150, verbose_name="first name"
            ),
        ),
        migrations.AlterField(
            model_name="user",
            name="lti_consumer",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="lti_toolbox.lticonsumer",
            ),
        ),
    ]
