{% extends 'board_base.html' %}
{% load i18n %}
{% load forum_conversation_tags %}

{% block sub_title %}{% trans "Edit post" %}{% endblock sub_title %}

{% block content %}
<div class="row">
  <div class="col-12">
    <h1>{{ topic.subject }}</h1>
  </div>
</div>
<div class="row">
  <div class="col-12">
    <div class="card post-edit">
      <div class="card-header">
        <h3 class="m-0 h5 card-title">{% trans "Edit post" %}</h3>
      </div>
      <div class="card-body">
        <form method="post" action="." class="form" enctype="multipart/form-data" novalidate>{% csrf_token %}
          {% include "forum_conversation/partials/post_form.html" %}
          <div class="form-actions">
            <input type="submit" class="btn btn-large btn-primary" value="{% trans "Submit" %}" />
          </div>
        </form>
      </div>
    </div>
  </div>
</div>
{% endblock content %}

{% block onbodyload %}
  machina.attachment.init();
{% endblock onbodyload %}

{% block extra_css %}
  {{ post_form.media.css }}
{% endblock extra_css %}

{% block extra_js %}
  {{ post_form.media.js }}
{% endblock extra_js %}
