# Generated by Django 3.1.4 on 2020-12-14 17:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ashley", "0003_auto_20200917_1335"),
    ]

    operations = [
        migrations.AlterField(
            model_name="user",
            name="public_username",
            field=models.CharField(
                blank=True,
                help_text="This username will be displayed with the user's posts",
                max_length=150,
                verbose_name="Public username",
            ),
        ),
    ]
