(self.webpackChunkashley=self.webpackChunkashley||[]).push([[82785],{82785:()=>{Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({data:{nu:["latn"],year:{0:"bu il",1:"gələn il",future:{one:"{0} il ərzində",other:"{0} il ərzində"},past:{one:"{0} il öncə",other:"{0} il öncə"},"-1":"keçən il"},"year-short":{0:"bu il",1:"gələn il",future:{one:"{0} il ərzində",other:"{0} il ərzində"},past:{one:"{0} il öncə",other:"{0} il öncə"},"-1":"keçən il"},"year-narrow":{0:"bu il",1:"gələn il",future:{one:"{0} il ərzində",other:"{0} il ərzində"},past:{one:"{0} il öncə",other:"{0} il öncə"},"-1":"keçən il"},quarter:{0:"bu rüb",1:"gələn rüb",future:{one:"{0} rüb ərzində",other:"{0} rüb ərzində"},past:{one:"{0} rüb öncə",other:"{0} rüb öncə"},"-1":"keçən rüb"},"quarter-short":{0:"bu rüb",1:"gələn rüb",future:{one:"{0} rüb ərzində",other:"{0} rüb ərzində"},past:{one:"{0} rüb öncə",other:"{0} rüb öncə"},"-1":"keçən rüb"},"quarter-narrow":{0:"bu rüb",1:"gələn rüb",future:{one:"{0} rüb ərzində",other:"{0} rüb ərzində"},past:{one:"{0} rüb öncə",other:"{0} rüb öncə"},"-1":"keçən rüb"},month:{0:"bu ay",1:"gələn ay",future:{one:"{0} ay ərzində",other:"{0} ay ərzində"},past:{one:"{0} ay öncə",other:"{0} ay öncə"},"-1":"keçən ay"},"month-short":{0:"bu ay",1:"gələn ay",future:{one:"{0} ay ərzində",other:"{0} ay ərzində"},past:{one:"{0} ay öncə",other:"{0} ay öncə"},"-1":"keçən ay"},"month-narrow":{0:"bu ay",1:"gələn ay",future:{one:"{0} ay ərzində",other:"{0} ay ərzində"},past:{one:"{0} ay öncə",other:"{0} ay öncə"},"-1":"keçən ay"},week:{0:"bu həftə",1:"gələn həftə",future:{one:"{0} həftə ərzində",other:"{0} həftə ərzində"},past:{one:"{0} həftə öncə",other:"{0} həftə öncə"},"-1":"keçən həftə"},"week-short":{0:"bu həftə",1:"gələn həftə",future:{one:"{0} həftə ərzində",other:"{0} həftə ərzində"},past:{one:"{0} həftə öncə",other:"{0} həftə öncə"},"-1":"keçən həftə"},"week-narrow":{0:"bu həftə",1:"gələn həftə",future:{one:"{0} həftə ərzində",other:"{0} həftə ərzində"},past:{one:"{0} həftə öncə",other:"{0} həftə öncə"},"-1":"keçən həftə"},day:{0:"bu gün",1:"sabah",future:{one:"{0} gün ərzində",other:"{0} gün ərzində"},past:{one:"{0} gün öncə",other:"{0} gün öncə"},"-1":"dünən"},"day-short":{0:"bu gün",1:"sabah",future:{one:"{0} gün ərzində",other:"{0} gün ərzində"},past:{one:"{0} gün öncə",other:"{0} gün öncə"},"-1":"dünən"},"day-narrow":{0:"bu gün",1:"sabah",future:{one:"{0} gün ərzində",other:"{0} gün ərzində"},past:{one:"{0} gün öncə",other:"{0} gün öncə"},"-1":"dünən"},hour:{0:"bu saat",future:{one:"{0} saat ərzində",other:"{0} saat ərzində"},past:{one:"{0} saat öncə",other:"{0} saat öncə"}},"hour-short":{0:"bu saat",future:{one:"{0} saat ərzində",other:"{0} saat ərzində"},past:{one:"{0} saat öncə",other:"{0} saat öncə"}},"hour-narrow":{0:"bu saat",future:{one:"{0} saat ərzində",other:"{0} saat ərzində"},past:{one:"{0} saat öncə",other:"{0} saat öncə"}},minute:{0:"bu dəqiqə",future:{one:"{0} dəqiqə ərzində",other:"{0} dəqiqə ərzində"},past:{one:"{0} dəqiqə öncə",other:"{0} dəqiqə öncə"}},"minute-short":{0:"bu dəqiqə",future:{one:"{0} dəqiqə ərzində",other:"{0} dəqiqə ərzində"},past:{one:"{0} dəqiqə öncə",other:"{0} dəqiqə öncə"}},"minute-narrow":{0:"bu dəqiqə",future:{one:"{0} dəqiqə ərzində",other:"{0} dəqiqə ərzində"},past:{one:"{0} dəqiqə öncə",other:"{0} dəqiqə öncə"}},second:{0:"indi",future:{one:"{0} saniyə ərzində",other:"{0} saniyə ərzində"},past:{one:"{0} saniyə öncə",other:"{0} saniyə öncə"}},"second-short":{0:"indi",future:{one:"{0} saniyə ərzində",other:"{0} saniyə ərzində"},past:{one:"{0} saniyə öncə",other:"{0} saniyə öncə"}},"second-narrow":{0:"indi",future:{one:"{0} saniyə ərzində",other:"{0} saniyə ərzində"},past:{one:"{0} saniyə öncə",other:"{0} saniyə öncə"}}},locale:"az"})}}]);
//# sourceMappingURL=82785.67a771b23f3fa5c26b30.index.js.map