# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-07 03:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("forum_permission", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="forumpermission",
            name="codename",
            field=models.CharField(
                db_index=True,
                max_length=150,
                unique=True,
                verbose_name="Permission codename",
            ),
        ),
        migrations.AlterField(
            model_name="forumpermission",
            name="is_global",
            field=models.BooleanField(
                db_index=True,
                default=False,
                help_text="This permission can be granted globally to all the forums",
                verbose_name="Global permission",
            ),
        ),
        migrations.AlterField(
            model_name="forumpermission",
            name="is_local",
            field=models.BooleanField(
                db_index=True,
                default=True,
                help_text="This permission can be granted individually for each forum",
                verbose_name="Local permission",
            ),
        ),
        migrations.AlterField(
            model_name="groupforumpermission",
            name="has_perm",
            field=models.BooleanField(
                db_index=True, default=True, verbose_name="Has perm"
            ),
        ),
        migrations.AlterField(
            model_name="userforumpermission",
            name="anonymous_user",
            field=models.BooleanField(
                db_index=True, default=False, verbose_name="Target anonymous user"
            ),
        ),
        migrations.AlterField(
            model_name="userforumpermission",
            name="has_perm",
            field=models.BooleanField(
                db_index=True, default=True, verbose_name="Has perm"
            ),
        ),
    ]
